==> pyside-setup-opensource-src-6.0.0.zip: pyside-setup-opensource-src-6.0.0/sources/pyside6/tests/QtWidgets/missing_symbols_test.py <==
#############################################################################
##
## Copyright (C) 2016 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''(Very) Simple test case for missing names from QtGui and QtWidgets'''

import os
import sys
import unittest

sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
from init_paths import init_test_paths
init_test_paths(False)

from PySide6 import QtGui
from PySide6 import QtWidgets

class MissingClasses(unittest.TestCase):
    def testQDrag(self): # Bug 222
        getattr(QtGui, 'QDrag')

    def testQDropEvent(self): # Bug 255
        getattr(QtGui, 'QDropEvent')

class MissingMembers(unittest.TestCase):

    def testQFontMetricsSize(self): # Bug 223
        QtGui.QFontMetrics.size

    def testQLayoutSetSpacing(self): # Bug 231
        QtWidgets.QLayout.setSpacing

    def testQImageLoad(self): # Bug 257
        QtGui.QImage.load

    def testQStandardItemModelinsertRow(self): # Bug 227
        QtGui.QStandardItemModel.insertRow

if __name__ == '__main__':
    unittest.main()

==> pyside-setup-opensource-src-6.1.2.zip: pyside-setup-opensource-src-6.1.2/sources/pyside6/tests/QtWidgets/missing_symbols_test.py <==
#############################################################################
##
## Copyright (C) 2016 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of the test suite of Qt for Python.
##
## $QT_BEGIN_LICENSE:GPL-EXCEPT$
## Commercial License Usage
## Licensees holding valid commercial Qt licenses may use this file in
## accordance with the commercial license agreement provided with the
## Software or, alternatively, in accordance with the terms contained in
## a written agreement between you and The Qt Company. For licensing terms
## and conditions see https://www.qt.io/terms-conditions. For further
## information use the contact form at https://www.qt.io/contact-us.
##
## GNU General Public License Usage
## Alternatively, this file may be used under the terms of the GNU
## General Public License version 3 as published by the Free Software
## Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
## included in the packaging of this file. Please review the following
## information to ensure the GNU General Public License requirements will
## be met: https://www.gnu.org/licenses/gpl-3.0.html.
##
## $QT_END_LICENSE$
##
#############################################################################

'''(Very) Simple test case for missing names from QtGui and QtWidgets'''

import os
import sys
import unittest

from pathlib import Path
sys.path.append(os.fspath(Path(__file__).resolve().parents[1]))
from init_paths import init_test_paths
init_test_paths(False)

from PySide6 import QtGui
from PySide6 import QtWidgets


class MissingClasses(unittest.TestCase):
    def testQDrag(self):  # Bug 222
        getattr(QtGui, 'QDrag')

    def testQDropEvent(self):  # Bug 255
        getattr(QtGui, 'QDropEvent')


class MissingMembers(unittest.TestCase):

    def testQFontMetricsSize(self):  # Bug 223
        QtGui.QFontMetrics.size

    def testQLayoutSetSpacing(self):  # Bug 231
        QtWidgets.QLayout.setSpacing

    def testQImageLoad(self):  # Bug 257
        QtGui.QImage.load

    def testQStandardItemModelinsertRow(self):  # Bug 227
        QtGui.QStandardItemModel.insertRow


if __name__ == '__main__':
    unittest.main()
